@@ -71,7 +71,8 @@ def get_script_name_key(job_type):
 def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_type=clusters.CLUSTER_TYPE_PERSISTENT,
                          git_ref='master', parameters=None, notify_on_job_finish=True, is_control_script=False,
                          pig_version=None, use_spot_instances=True, pipeline_job_id=None, job_type=JOB_TYPE_PIG,
-                         cluster_tags=[], instance_type=None, project_build=None, cluster_configuration=None):
+                         cluster_tags=[], instance_type=None, project_build=None, cluster_configuration=None,
+                         job_description=None):
     """
     Post a new job to a new cluster.
 
@@ -123,6 +124,9 @@ def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_t
     :type project_build: string
     :param project_build: ID of the static project build that should be used, either a branch name or a githash.
 
+    :type job_description: string
+    :param job_description: Description to be displayed as a hint in Mortar web.
+
     :raises: requests.exception.HTTPError: if a 40x or 50x error occurs
 
     :rtype: str:
@@ -141,7 +145,8 @@ def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_t
             'job_type': job_type,
             get_script_name_key(job_type): script_name,
             'project_build': project_build,
-            'cluster_configuration': cluster_configuration
+            'cluster_configuration': cluster_configuration,
+            'job_description': job_description
     }
 
     if pig_version:
@@ -152,7 +157,7 @@ def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_t
 
 def post_web_job_new_cluster(api, script_name, cluster_size, cluster_type=clusters.CLUSTER_TYPE_PERSISTENT,
                              parameters=None, notify_on_job_finish=True, pig_version=None, use_spot_instances=True,
-                             job_type=JOB_TYPE_PIG, cluster_configuration=None):
+                             job_type=JOB_TYPE_PIG, cluster_configuration=None, job_description=None):
     """
     Post a new job to a new cluster.
 
@@ -183,6 +188,9 @@ def post_web_job_new_cluster(api, script_name, cluster_size, cluster_type=cluste
     :type job_type: string
     :param job_type: Type of the job. Default: pig.
 
+    :type job_description: string
+    :param job_description: Description to be displayed as a hint in Mortar web.
+
     :raises: requests.exception.HTTPError: if a 40x or 50x error occurs
 
     :rtype: str:
@@ -196,7 +204,8 @@ def post_web_job_new_cluster(api, script_name, cluster_size, cluster_type=cluste
             'use_spot_instances': use_spot_instances,
             'job_type': job_type,
             get_script_name_key(job_type): script_name,
-            'cluster_configuration': cluster_configuration
+            'cluster_configuration': cluster_configuration,
+            'job_description': job_description
     }
 
     if pig_version:
@@ -208,7 +217,8 @@ def post_web_job_new_cluster(api, script_name, cluster_size, cluster_type=cluste
 
 def post_job_existing_cluster(api, project_name, script_name, cluster_id, cluster_type=clusters.CLUSTER_TYPE_PERSISTENT,
                               git_ref='master', parameters=None, notify_on_job_finish=True, is_control_script=False,
-                              pig_version=None, pipeline_job_id=None, job_type=JOB_TYPE_PIG, project_build=None):
+                              pig_version=None, pipeline_job_id=None, job_type=JOB_TYPE_PIG, project_build=None,
+                              job_description=None):
     """
     Post a new job to an existing cluster.
 
@@ -245,6 +255,9 @@ def post_job_existing_cluster(api, project_name, script_name, cluster_id, cluste
     :type project_build: string
     :param project_build: ID of the static project build that should be used, either a branch name or a githash.
 
+    :type job_description: string
+    :param job_description: Description to be displayed as a hint in Mortar web.
+
     :raises: requests.exception.HTTPError: if a 40x or 50x error occurs
 
     :rtype: str:
@@ -258,7 +271,8 @@ def post_job_existing_cluster(api, project_name, script_name, cluster_id, cluste
             'pipeline_job_id': pipeline_job_id,
             'job_type': job_type,
             get_script_name_key(job_type): script_name,
-            project_build: project_build
+            'project_build': project_build,
+            'job_description': job_description
     }
 
     if pig_version:
@@ -267,7 +281,8 @@ def post_job_existing_cluster(api, project_name, script_name, cluster_id, cluste
     return api.post('jobs', body)['job_id']
 
 def post_web_job_existing_cluster(api, script_name, cluster_id, parameters=None,
-                                  notify_on_job_finish=True, pig_version=None, job_type=JOB_TYPE_PIG):
+                                  notify_on_job_finish=True, pig_version=None, job_type=JOB_TYPE_PIG,
+                                  job_description=None):
     """
     Post a new job to an existing cluster.
 
@@ -289,6 +304,9 @@ def post_web_job_existing_cluster(api, script_name, cluster_id, parameters=None,
     :type pig_version: string
     :param pig_version: Major version of pig to run.  If null, uses the Mortar platform default (currently 0.9).
 
+    :type job_description: string
+    :param job_description: Description to be displayed as a hint in Mortar web.
+
     :raises: requests.exception.HTTPError: if a 40x or 50x error occurs
 
     :rtype: str:
@@ -299,7 +317,8 @@ def post_web_job_existing_cluster(api, script_name, cluster_id, parameters=None,
             'parameters': parameters or {},
             'notify_on_job_finish': notify_on_job_finish,
             'job_type': job_type,
-            get_script_name_key(job_type): script_name
+            get_script_name_key(job_type): script_name,
+            'job_description': job_description
     }
 
     return api.post('jobs', body)['job_id']
